@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe 'neutron::agents::ml2::ovs' do
   let :pre_condition do
-    "class { 'neutron': rabbit_password => 'passw0rd' }"
+    "class { 'neutron': }"
   end
 
   let :default_params do
@@ -46,11 +46,9 @@ describe 'neutron::agents::ml2::ovs' do
       is_expected.to contain_neutron_agent_ovs('agent/drop_flows_on_start').with_value(p[:drop_flows_on_start])
       is_expected.to contain_neutron_agent_ovs('agent/extensions').with_value(['<SERVICE DEFAULT>'])
       is_expected.to contain_neutron_agent_ovs('agent/minimize_polling').with_value(['<SERVICE DEFAULT>'])
-      is_expected.to contain_neutron_agent_ovs('agent/tunnel_csum').with_value(['<SERVICE DEFAULT>'])
       is_expected.to contain_neutron_agent_ovs('ovs/datapath_type').with_value(['<SERVICE DEFAULT>'])
       is_expected.to contain_neutron_agent_ovs('ovs/vhostuser_socket_dir').with_value(['<SERVICE DEFAULT>'])
       is_expected.to contain_neutron_agent_ovs('ovs/ovsdb_interface').with_value(['<SERVICE DEFAULT>'])
-      is_expected.to contain_neutron_agent_ovs('ovs/of_interface').with_value(['<SERVICE DEFAULT>'])
       is_expected.to contain_neutron_agent_ovs('ovs/integration_bridge').with_value(p[:integration_bridge])
       is_expected.to contain_neutron_agent_ovs('securitygroup/firewall_driver').\
         with_value(p[:firewall_driver])
@@ -280,24 +278,6 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
-    context 'when supplying of_interface' do
-      context 'with incorrect value' do
-        before :each do
-          params.merge!(:of_interface => 'random')
-        end
-        it_raises 'a Puppet::Error', /A value of \$of_interface is incorrect. The allowed values are ovs-ofctl and native/
-      end
-
-      context 'with supported value' do
-        before :each do
-          params.merge!(:of_interface => 'native')
-        end
-        it 'should configure of_interface for ovs' do
-          is_expected.to contain_neutron_agent_ovs('ovs/of_interface').with_value('native')
-        end
-      end
-    end
-
     context 'when enabling dpdk with manage vswitch disabled' do
       before :each do
         params.merge!(:enable_dpdk => true, :manage_vswitch => false)
