@@ -6,7 +6,6 @@ describe 'neutron' do
     { :package_ensure        => 'present',
       :core_plugin           => 'ml2',
       :auth_strategy         => 'keystone',
-      :rabbit_password       => 'guest',
       :log_dir               => '/var/log/neutron',
       :purge_config          => false,
     }
@@ -19,45 +18,7 @@ describe 'neutron' do
   end
 
   shared_examples_for 'neutron' do
-
-    context 'and if rabbit_host parameter is provided' do
-      it_configures 'a neutron base installation'
-    end
-
-    context 'and if rabbit_hosts parameter is provided' do
-
-      context 'with one server' do
-        before { params.merge!( :rabbit_hosts => ['127.0.0.1:5672'] ) }
-        it_configures 'a neutron base installation'
-        it_configures 'rabbit HA with a single virtual host'
-      end
-
-      context 'with multiple servers' do
-        before { params.merge!( :rabbit_hosts => ['rabbit1:5672', 'rabbit2:5672'] ) }
-        it_configures 'a neutron base installation'
-        it_configures 'rabbit HA with multiple hosts'
-      end
-
-      context 'with rabbit_ha_queues set to false and with rabbit_hosts' do
-        before { params.merge!( :rabbit_ha_queues => 'false',
-                                :rabbit_hosts => ['rabbit:5673'] ) }
-        it_configures 'rabbit_ha_queues set to false'
-      end
-
-      context 'with non-default notification options' do
-        before { params.merge!( :notification_driver => 'messagingv2',
-                                :notification_topics => 'notifications',
-                                :notification_transport_url => 'rabbit://me:passwd@host:5672/virtual_host' ) }
-        it_configures 'notification_driver and notification_topics'
-      end
-
-      it 'configures logging' do
-        is_expected.to contain_oslo__log('neutron_config').with(:log_file   => '<SERVICE DEFAULT>',
-                                                                :log_dir    => params[:log_dir],
-                                                                :use_stderr => '<SERVICE DEFAULT>')
-      end
-
-    end
+    it_configures 'a neutron base installation'
 
     context 'with rabbitmq heartbeat configured' do
       before { params.merge!( :rabbit_heartbeat_timeout_threshold => '60', :rabbit_heartbeat_rate => '10' ) }
@@ -92,8 +53,6 @@ describe 'neutron' do
     it_configures 'with transport_url defined'
     it_configures 'with rootwrap daemon'
     it_configures 'with max_allowed_address_pair defined'
-    it_configures 'when disabling vlan_transparent'
-    it_configures 'when enabling vlan_transparent'
 
     context 'with amqp messaging' do
       it_configures 'amqp support'
@@ -124,11 +83,7 @@ describe 'neutron' do
       is_expected.to contain_neutron_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
     end
 
-    it 'configures credentials for rabbit' do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_userid').with_value( '<SERVICE DEFAULT>' )
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_password').with_value( params[:rabbit_password] )
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_password').with_secret( true )
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value( '<SERVICE DEFAULT>' )
+    it 'configures rabbit' do
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value( '<SERVICE DEFAULT>' )
@@ -156,32 +111,13 @@ describe 'neutron' do
       is_expected.to contain_neutron_config('DEFAULT/state_path').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_concurrency/lock_path').with_value('$state_path/lock')
       is_expected.to contain_neutron_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/vlan_transparent').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('DEFAULT/rpc_response_timeout').with_value( '<SERVICE DEFAULT>' )
       is_expected.to contain_neutron_config('agent/root_helper').with_value('sudo neutron-rootwrap /etc/neutron/rootwrap.conf')
       is_expected.to contain_neutron_config('agent/root_helper_daemon').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('agent/report_interval').with_value('<SERVICE DEFAULT>')
     end
   end
 
-  shared_examples_for 'rabbit HA with a single virtual host' do
-    it 'in neutron.conf' do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts] )
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-    end
-  end
-
-  shared_examples_for 'rabbit HA with multiple hosts' do
-    it 'in neutron.conf' do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts].join(',') )
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-    end
-  end
-
   shared_examples_for 'rabbit with heartbeat configured' do
     it 'in neutron.conf' do
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
@@ -398,28 +334,6 @@ describe 'neutron' do
     }
   end
 
-  shared_examples_for  'when disabling vlan_transparent' do
-    before do
-      params.merge!(
-        :vlan_transparent => false
-      )
-    end
-    it do
-      is_expected.to contain_neutron_config('DEFAULT/vlan_transparent').with_value(false)
-    end
-  end
-
-  shared_examples_for 'when enabling vlan_transparent' do
-    before do
-      params.merge!(
-        :vlan_transparent => true
-      )
-    end
-    it do
-      is_expected.to contain_neutron_config('DEFAULT/vlan_transparent').with_value(true)
-    end
-  end
-
   shared_examples_for 'without service_plugins' do
     it { is_expected.not_to contain_neutron_config('DEFAULT/service_plugins') }
   end
@@ -517,7 +431,7 @@ describe 'neutron' do
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>') }
     end
 
-    context 'with overriden amqp parameters' do
+    context 'with overridden amqp parameters' do
       before { params.merge!(
         :amqp_idle_timeout  => '60',
         :amqp_trace         => true,
