@@ -3,14 +3,17 @@ require 'spec_helper'
 describe 'neutron::plugins::cisco' do
 
   let :pre_condition do
-    "class { 'neutron::server': auth_password => 'password'}
-     class { 'neutron': rabbit_password => 'passw0rd' }"
+    "class { '::neutron::keystone::authtoken':
+      password => 'passw0rd',
+     }
+     class { 'neutron::server': }
+     class { 'neutron': }"
   end
 
   let :params do
     { :keystone_username => 'neutron',
       :keystone_password => 'neutron_pass',
-      :keystone_auth_url => 'http://127.0.0.1:35357/v2.0/',
+      :keystone_auth_url => 'http://127.0.0.1:5000/v2.0/',
       :keystone_tenant   => 'tenant',
 
       :database_name     => 'neutron',
