@@ -24,12 +24,11 @@ describe 'neutron::plugins::ml2' do
 
   let :pre_condition do
     "class { 'neutron':
-      rabbit_password => 'passw0rd',
       core_plugin     => 'ml2' }"
   end
 
   let :default_params do
-    { :type_drivers          => ['local', 'flat', 'vlan', 'gre', 'vxlan'],
+    { :type_drivers          => ['local', 'flat', 'vlan', 'gre', 'vxlan', 'geneve'],
       :tenant_network_types  => ['local', 'flat', 'vlan', 'gre', 'vxlan'],
       :mechanism_drivers     => ['openvswitch', 'linuxbridge'],
       :flat_networks         => '*',
