@@ -4,9 +4,11 @@ describe 'neutron::plugins::nuage' do
 
   let :pre_condition do
     "class { 'neutron':
-      rabbit_password => 'passw0rd',
       core_plugin     => 'nuage_neutron.plugins.nuage.plugin.NuagePlugin' }
-     class { 'neutron::server': password => 'password' }"
+      class { '::neutron::keystone::authtoken':
+        password => 'passw0rd',
+      }
+      class { 'neutron::server': }"
   end
 
   let :test_facts do
@@ -60,7 +62,6 @@ describe 'neutron::plugins::nuage' do
     context 'configure nuage with wrong core_plugin configure' do
       let :pre_condition do
         "class { 'neutron':
-          rabbit_password => 'passw0rd',
           core_plugin     => 'foo' }"
       end
 
@@ -129,4 +130,3 @@ describe 'neutron::plugins::nuage' do
   end
 
 end
-
